#
# spec file for package sane-backends
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

# Cf. https://rpm.org/user_doc/conditional_builds.html
# by default enable support for PWG eSCL network backend
%bcond_without escl
# by default disable support for PWG eSCL network backend
#bcond_with escl

Name:           sane-backends
BuildRequires:  gcc-c++
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libtiff-devel
BuildRequires:  libv4l-devel
BuildRequires:  net-snmp-devel
BuildRequires:  pkgconfig
%if %{with escl}
BuildRequires:  pkgconfig(avahi-client) >= 0.6.24
BuildRequires:  pkgconfig(libcurl)
# since sane-backends 1.0.31 the escl backend requires libpoppler-glib-devel
# cf. https://gitlab.com/sane-project/backends/-/blob/master/INSTALL.linux
BuildRequires:  libpoppler-glib-devel
%endif
BuildRequires:  pkgconfig(libusb-1.0)
# The pixma backend requires libxml2
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(systemd)
%systemd_requires

Summary:        SANE (Scanner Access Now Easy) Scanner Drivers
License:        GPL-2.0+ and SUSE-GPL-2.0+-with-sane-exception and SUSE-Public-Domain
Group:          Hardware/Scanner
Version:        1.0.31
Release:        lp151.6.3.1
Url:            http://www.sane-project.org/
# On https://gitlab.com/sane-project/backends/-/releases
# there are two links, the first one is called "Source code (tar.gz)" that pints to
# https://gitlab.com/sane-project/backends/-/archive/1.0.31/backends-1.0.31.tar.gz
# and the second one is called "sane-backends-1.0.31.tar.gz" that pints to
# https://gitlab.com/sane-project/backends/uploads/8bf1cae2e1803aefab9e5331550e5d5d/sane-backends-1.0.31.tar.gz
# The first one "backends-1.0.31.tar.gz" does not build, as it does not contain a prebuilt configure script,
# and autoconf fails as it requires a complete git clone, see https://gitlab.com/sane-project/backends/issues/248
# We use the second one "sane-backends-1.0.31.tar.gz" that is a dist tarball with a prebuilt configure script via
# wget https://gitlab.com/sane-project/backends/uploads/8bf1cae2e1803aefab9e5331550e5d5d/sane-backends-1.0.31.tar.gz
Source0:        sane-backends-1.0.31.tar.gz
# Source100... is SUSE specific stuff:
# Source102 is the OpenSLP registration file for the saned:
Source102:      sane.reg
# Source110 creates our hpaio.desc file directly from the models.dat file of HPLIP:
Source110:      create_hpaio.desc_from_models.dat
# Source111 is the models.dat file of HPLIP:
Source111:      models.dat
# Was initially just dumped in as Source1 to "package baselibs.conf"
# (see the matching explanatory entry in the RPM changelog):
Source190:      baselibs.conf
# Source200... is scanner autoconfiguration stuff:
# Source200 and Source201 generate the 56-sane-backends-autoconfig.rules file
# for automated scanner driver activation via udev ("scanner autoconfiguration").
# Source200 is a copy of /usr/lib/YaST2/bin/create_scanner_database
# to avoid yast2-scanner in BuildRequires which would drag in almost the whole YaST:
Source200:      create_scanner_database
# Source201 actually generates the 56-sane-backends-autoconfig.rules file
# by reading scanner.database which was created before by create_scanner_database
# to extract the needed info from which create_sane-backends-autoconfig.rules
# generates the 56-sane-backends-autoconfig.rules file:
Source201:      create_sane-backends-autoconfig.rules
# Sources 202 and 203 are files to enable socket based service activation which replaced xinetd
Source202:      saned@.service
Source203:      saned.socket
# Patch100... is SUSE specific stuff:
# Patch102 adapt_epkowa.desc_for_yast2-scanner.patch adapts epkowa.desc for yast2-scanner
# (see https://bugzilla.novell.com/show_bug.cgi?id=788756#c14).
# It adds "requires DFSG non-free Image Scan software from Avasys" to all comments
# (or adds such a comment if there is not yet a comment) so that yast2-scanner
# (via "requires DFSG non-free" string match in create_scanner_database)
# shows always the info regarding "Image Scan" download from Avasys
# (compare https://bugzilla.novell.com/show_bug.cgi?id=569917
#  and https://bugzilla.novell.com/show_bug.cgi?id=746038).
# Furthermore it removes "unsupported" models from epkowa.desc because
# otherwise there would be confusing model entries shown in yast2-scanner:
Patch102:       adapt_epkowa.desc_for_yast2-scanner.patch
# Install into this non-root directory (required when norootforbuild is used):
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# Prerequire /sbin/ldconfig which is used in the traditional bash scriptlets for post/postun:
PreReq:         /sbin/ldconfig
# See https://bugzilla.novell.com/show_bug.cgi?id=437293
%ifarch ppc64
Obsoletes:      sane-64bit
%endif
# Up to SLE10 there was the package name 'sane' for 'sane-backends'.
# Therefore this RPM provides 'sane' and it also obsoletes it.
# The {version} is needed in both Provides and Obsoletes
# to avoid a RPMLINT warning that the package obsoletes itself:
Provides:       sane = %{version}
Obsoletes:      sane < %{version}
# Skip testing devel dependencies required by libtool .la files by the following comment:
# skip-check-libtool-deps

%description
The software consists of SANE scanner drivers,
"scanimage," and the "saned" daemon.

A SANE scanner driver is used via a SANE front-end.
This package contains the command line front-end "scanimage".
There are graphical front-ends in other packages like
XSane (package xsane), Skanlite for KDE4 (package skanlite),
and Kooka for KDE3 (package kdegraphics3-scan).

The "saned" daemon provides the service "sane-port"
to access scanners that are connected to a server
via network from client hosts that run the "net" meta driver.

%package devel
Summary:        Development files for sane-backends
License:        GPL-2.0+ and SUSE-GPL-2.0+-with-sane-exception and SUSE-Public-Domain
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       net-snmp-devel

%description devel
This package contains the development files for sane-backends.

%package autoconfig
Summary:        USB Scanner Autoconfiguration
License:        GPL-2.0+ and LGPL-2.1+ and SUSE-Public-Domain
Group:          Hardware/Scanner
Requires:       sane-backends
# When sane-backends is already installed, try to install also sane-backends-autoconfig if available:
Supplements:    sane-backends

%description autoconfig
USB scanner autoconfiguration happens via udev.

The file /etc/udev/rules.d/56-sane-backends-autoconfig.rules contains
entries for those USB scanners where the USB IDs are known, which are
supported by a free driver, where the support status is "complete" or
"good", and which do not require firmware upload.

When a USB scanner is connected and its USB IDs match to an entry in
the 56-sane-backends-autoconfig.rules file, the matching scanner driver
is activated (i.e. the driver line in /etc/sane.d/dll.conf is
activated).

It enables scanner drivers but never disables them. The reason is that
enabled drivers do not hurt so that an automated disable would make it
only overcomplicated because when more than one scanner uses the same
driver, a complicated check would be needed to avoid that the driver is
accidentally disabled when only one scanner was disconnected.

If you do not like automated driver activation, do not install this
package or remove it when it is already installed.

%prep
%setup -q
# Remove hpoj.desc completely to avoid confusion with its successor hpaio.desc
# because since openSUSE 10.3 the package hp-officeJet (for hpoj.desc) is dropped.
sed -i -e '/descriptions-external\/hpoj.desc / d' doc/Makefile{.am,.in}
rm doc/descriptions-external/hpoj.desc
# For compliance with the other description files in the sane-backends sources
# change the manufacturer name from "Hewlett Packard" to "Hewlett-Packard":
for d in doc/descriptions-external/hp3770.desc doc/descriptions-external/hp8200.desc
do sed -i -e '/^:mfg/s/Hewlett Packard/Hewlett-Packard/' $d
done
# Patch100... is SUSE specific stuff:
# Patch102 adapt_epkowa.desc_for_yast2-scanner.patch adapts epkowa.desc for yast2-scanner
# see https://bugzilla.opensuse.org/show_bug.cgi?id=788756#c14
%patch102
# Source100... is SUSE specific stuff:
# Create our hpaio.desc descriptions-external file
# (use it as bash input because sources may be installed without execute permissions):
bash %{SOURCE110} <%{SOURCE111} >doc/descriptions-external/hpaio.desc
# Copy the create_scanner_database script from the sources directory to the build directory
# to avoid that the original source becomes modified later in the install section
# and ends up in the source RPM, see https://bugzilla.novell.com/show_bug.cgi?id=463464#c11
cp %{SOURCE200} create_scanner_database
chmod u+x create_scanner_database

%build
export CFLAGS="%{optflags} -D_GNU_SOURCE -DGIMP_ENABLE_COMPAT_CRUFT=1 -fno-strict-aliasing"
export LDFLAGS="-L/%_lib $LDFLAGS"
# Enable pthread instead of fork (used in Debian since Feb 2009 and no issues so far),
# see https://bugzilla.novell.com/show_bug.cgi?id=633780
# Disable locking because /var/lock/sane/ would be a world-writable directory.
./configure --prefix=/usr \
            --exec-prefix=/usr \
            --sysconfdir=%{_sysconfdir} \
            --libdir=%{_libdir} \
            --sbindir=%{_sbindir} \
            --mandir=%{_mandir} \
            --datadir=%{_datadir} \
            --docdir=%{_defaultdocdir}/sane-backends \
            --enable-pthread \
            --with-usb \
%if %{with escl}
            --with-avahi \
%endif
            --disable-locking
# Enable locking for backends where "99" is the group of the lockfile path (LOCKPATH_GROUP)
# because "99" is the group of the user who runs the build when norootforbuild is used
# and set localstatedir to have the lock files in /var/lock/sane (see backend/Makefile.in).
# Disabled because locking requires a world-writable /var/lock/sane/ directory:
#            --enable-locking \
#            --with-group=99 \
#            --localstatedir=/var
make

%install
make install DESTDIR=%{buildroot}
# The actual driver modules are installed as libsane-<driver>.so.{version}
# and two libsane-<driver>.so.1 and libsane-<driver>.so links point to them.
# Additionally a libsane-<driver>.la libtool archive file is installed
# which could be used to find the correct module file name to dlopen the module.
# Only the dll meta-backend (/usr/lib/libsane.so.1.0.19) links with driver modules.
# The dll meta-backend looks only for libsane-<driver>.so.1 and uses dlopen(3) directly.
# The dll meta-backend needs neither libsane-<driver>.so nor libsane-<driver>.la.
# RPMLINT complains about libsane-<driver>.so with "devel-file-in-non-devel-package".
# Therefore the libsane-<driver>.so and libsane-<driver>.la files are simply removed.
rm %{buildroot}%{_libdir}/sane/libsane-*.so
rm %{buildroot}%{_libdir}/sane/libsane-*.la
# Because of https://bugzilla.novell.com/show_bug.cgi?id=592143 for openSUSE 11.3
# even the /usr/lib/libsane.la file for the dll meta-backend is removed
# regardless that it is unknown how whatever third-party scanning frontend
# may like to link with SANE (i.e. with the dll meta-backend).
# The frontends which are provided by openSUSE /usr/bin/scanimage,
# /usr/bin/xsane, and /usr/bin/skanlite do not need it.
# The /usr/lib/libsane.so link for the dll meta-backend is kept because it is needed
# during build-time by other packages which need sane-backends to build.
rm %{buildroot}%{_libdir}/libsane.la
# Disable all backends in /etc/sane.d/dll.conf to avoid problems when backends are active by default:
perl -pi -e 's/^([^#].*)$/#$1/' %{buildroot}%{_sysconfdir}/sane.d/dll.conf
# Allow all users to write into /var/lock/sane/ so that the backends work for normal users
# and set the sticky bit (i.e. others are not allowed to remove lock files).
# Disabled because package-specific world-writable directories are not allowed:
#chmod 1777 {buildroot}/var/lock/sane/
# Install the descriptions and descriptions-external files.
# These files are the sources to make {_defaultdocdir}/sane/sane-backends/*.html
# but these source files must also exist in the installed sane package
# because YaST needs them to create its scanner database:
for d in descriptions descriptions-external
do install -d -m755 %{buildroot}%{_datadir}/sane/$d
   install -m644 doc/$d/*.desc %{buildroot}%{_datadir}/sane/$d
done
# Add ':firmware "required"' entries for the respective scanners to the descriptions files
# so that YaST can show firmware upload related information to the user of such a scanner.
# This must be done after build because those entries are a SUSE specific extension.
# To determine scanners which require firmware upload, search the man pages
# for backends which provide support for firmware upload.
# Use a command like
#   for m in /usr/share/man/man5/sane-*
#   do man -E ascii -P cat -l $m 2>/dev/null | grep -q -i firmware && echo $m
#   done
# to find backend man pages which mention "firmware".
# In version 1.0.19 the following man pages mention "firmware":
#   sane-agfafocus: mentiones only "firmware revision" (no firmware upload)
#   sane-apple: mentiones only "firmware revision" (no firmware upload)
#   sane-artec: mentiones only "problems with firmware v1.92" (no firmware upload)
#   sane-artec_eplus48u: "you need a firmware file for your scanner" (unconditioned firmware upload)
#   sane-bh: mentiones only "requires RSC firmware level 1.5" (no firmware upload)
#   sane-epjitsu: "these scanners require a firmware file" (unconditioned firmware upload)
#   sane-gt68xx: "you need a firmware file for your scanner" (unconditioned firmware upload)
#   sane-hp: mentiones only "no firmware support for contrast" (no firmware upload)
#   sane-matsushita: mentiones only "scanner with proper firmware" (no firmware upload)
#   sane-microtek2: mentiones only "firmware of the scanner provides" (no firmware upload)
#   sane-sharp: mentiones only "bug in the firmware" (no firmware upload)
#   sane-snapscan: "USB scanners ... scanners that need a firmware upload" (conditioned firmware upload)
#   sane-st400: mentiones only "firmware revision" (no firmware upload)
#   sane-teco2: mentiones only "firmware 1.09" (no firmware upload)
# As far as we know all scanners which use
# the backend gt68xx and the related backend artec_eplus48u
# or the backend epjitsu require a firmware upload,
# see "man sane-gt68xx" and http://www.meier-geinitz.de/sane/gt68xx-backend/
# and see "man sane-artec_eplus48u" and "man sane-epjitsu":
for b in gt68xx artec_eplus48u epjitsu
do sed -i -e 's/^:model.*$/&\n:firmware "required"/' %{buildroot}%{_datadir}/sane/descriptions/$b.desc
done
# As far as we know (almost) all USB scanners (but not the SCSI scanners)
# which use the backend snapscan require a firmware upload,
# see "man sane-snapscan" and http://snapscan.sourceforge.net/:
sed -i -e 's/^:interface "USB".*$/&\n:firmware "required"/' %{buildroot}%{_datadir}/sane/descriptions/snapscan.desc
# Only the "SnapScan 1236u" needs no firmware upload (see Suse/Novell bug #73960):
sed -i -e '/:model "SnapScan 1236u"/,/:firmware "required"/s/required//' %{buildroot}%{_datadir}/sane/descriptions/snapscan.desc
# Scanner autoconfiguration stuff (packaged in sane-backends-autoconfig):
# It must be done before the udev libsane.rules stuff because the scanner database is needed there.
# This requires the installed descriptions and descriptions-external files
# because create_scanner_database reads the description files to extract the needed info
# to create the scanner database from which create_sane-backends-autoconfig.rules
# extracts the needed info to generate the 56-sane-backends-autoconfig.rules file
# for automated scanner driver activation via udev.
# Note that driver activation alone is not sufficient
# to have a usable "scanner autoconfiguration" for the user.
# What is also needed are appropriate USB device file permissions
# so that the user's scanning software can access the device.
# But this is already in place via the the udev libsane.rules file
# which contains a superset of USB scanner IDs (all known USB scanner IDs)
# compared to the USB scanner IDs in 56-sane-backends-autoconfig.rules,
# see create_sane-backends-autoconfig.rules for which USB scanners
# automated driver activation is done (basically only those scanners
# which are supported by a free driver, which do not require firmware upload,
# and where the support status is "complete" or "good").
# Modify create_scanner_database to find the description files in the BuildRoot directory
# (the usual delimiter '/' cannot be used because buildroot contains it too):
sed -i -e 's|/usr/share/sane/descriptions|%{buildroot}/usr/share/sane/descriptions|' create_scanner_database
# Create the scanner database and store it because it is also needed later
# to disable "unsupported" model entries in the udev libsane.rules file.
# The file name "scanner.database" is used hardcoded in create_sane-backends-autoconfig.rules.
./create_scanner_database >scanner.database
# Run create_sane-backends-autoconfig.rules which reads scanner.database
# (use it as bash input because sources may be installed without execute permissions):
bash %{SOURCE201} >autoconfig.rules
# Install the scanner autoconfiguration udev rules file:
install -d %{buildroot}%{_sysconfdir}/udev/rules.d
install -m644 autoconfig.rules %{buildroot}%{_sysconfdir}/udev/rules.d/56-sane-backends-autoconfig.rules
# Since version 1.0.19 there is udev and HAL support.
# Therefore the old/outdated hotplug stuff is dropped (was never used by openSUSE).
# Neither tools/hotplug/libsane.usermap nor tools/hotplug/libusbscanner is installed.
# Also the evil-hack init-script "sane-dev" is no longer provided.
# Regarding udev:
# Modify the generated tools/udev/libsane.rules file as follows:
# All GROUP="scanner" are replaced by GROUP="lp".
# There is no group "scanner" in /etc/group for openSUSE.
# For all-in-one devices (i.e. printer + scanner, e.g. "EPSON Stylus" devices)
# the group must be "lp" so that the CUPS usb backend which runs
# as user "lp" (who is member of the group "lp") can send printing data
# to the printer unit (i.e. the printer interface of the USB device).
# It is sufficiently secure and reasonable easy to use by default
# the same group "lp" for printers and scanners because both kind of devices
# usually require physical user access (to get the printed paper or
# to place a paper on the scanner) so that both kind of devices
# should usually require the same kind of security.
sed -i -e 's/GROUP="scanner"/GROUP="lp"/' tools/udev/libsane.rules
# Regarding SUBSYSTEM=="usb" see the Novell/Suse Bugzilla bug
# https://bugzilla.novell.com/show_bug.cgi?id=294161#c11
sed -i -e '/^SUBSYSTEM/s/"usb_device"/"usb"/' tools/udev/libsane.rules
# Regarding ATTRS{} (formerly SYSFS{}) versus ATTR{} see the Novell/Suse Bugzilla bug
# https://bugzilla.novell.com/show_bug.cgi?id=436085#c0
# but for SCSI scanners "ATTRS" is mandatory see the Novell/Suse Bugzilla bug
# https://bugzilla.novell.com/show_bug.cgi?id=681146#c20
# so that "ATTRS" is replaced by "ATTR" only for USB scanners.
sed -i -e '/^LABEL="libsane_usb_rules_begin"/,/^LABEL="libsane_usb_rules_end"/s/ATTRS/ATTR/g' tools/udev/libsane.rules
# Disable all ENV{DEVTYPE} lines because we (Suse/Novell) do not need them.
sed -i -e 's/^ENV{DEVTYPE}/# ENV{DEVTYPE}/' tools/udev/libsane.rules
# Disable entries for USB scanners which are "unsupported"
# but keep the entries for models for which the support status
# is "complete", "good", "basic", "minimal", "untested"
# because libsane.rules disables USB autosuspend
# which is needed as safe default for any scanner
# (regardless to what extent it is actually supported).
# The only exception are unsupported models
# because it seems to be wrong to have "known but unsupported" devices
# listed in the libsane.rules file because it seems not to make sense
# to set owner, group, and permissions for devices which are not
# supported by SANE which would even cause conflicts if such a
# device is supported by whatever other software,
# see https://bugzilla.novell.com/show_bug.cgi?id=439193
# Extract a list of USB IDs for "unsupported" scanners and store them in unsupportedUSBIDs.
# It can happen that there is a status "unsupported" entry for a backend
# for a model which is actually supported by another backend, for example
# the "Epson Perfection 1670" is "unsupported" by the "epkowa" backend
# but works "good" with the "snapscan" backend
# see https://bugzilla.novell.com/show_bug.cgi?id=439193#c6
cat /dev/null >unsupportedUSBIDs
for USBID in $( grep '||[^|]*|0x[0-9A-Fa-f][0-9A-Fa-f]*:0x[0-9A-Fa-f][0-9A-Fa-f]*|unsupported|' scanner.database | cut -s -d '|' -f 7 | sort -f -u )
do grep -o "|$USBID|.*|" scanner.database | grep -E -q 'complete|good|basic|minimal|untested' || echo $USBID >>unsupportedUSBIDs
done
# Ignore case when using sed to avoid possible problems
# with upper case letters in the USB IDs:
for m in $( sed -e 's/0x/./ig' -e 's/:/.,.ATTR.idProduct.==/' unsupportedUSBIDs )
do if grep -q "^ATTR.idVendor.==$m" tools/udev/libsane.rules
   then echo "Disabling unsupported model matching ATTR.idVendor.==$m"
        sed -i -e "/^ATTR.idVendor.==$m/Is/^ATTR/# ATTR/" tools/udev/libsane.rules
   fi
done
# Newer udev versions complain about NAME="%k" usage with warning messages like
#  'udevd[1234]: NAME="%k" is superfluous and breaks kernel supplied names...'
sed -i -e 's/NAME="%k", //' tools/udev/libsane.rules
# Add an entry for "SCSI processor EPSON Perfection1640",
# see https://bugzilla.novell.com/show_bug.cgi?id=681146#c43
sed -i -e '/^# Epson Perfection 636S /i# Epson Perfection 1640\nKERNEL=="sg[0-9]*", ATTRS{type}=="3", ATTRS{vendor}=="EPSON", ATTRS{model}=="Perfection1640", MODE="0664", GROUP="lp", ENV{libsane_matched}="yes"' tools/udev/libsane.rules
# Add a wildcard entry for any "SCSI processor EPSON SCANNER*"
# see http://lists.alioth.debian.org/pipermail/sane-devel/2011-June/028739.html
sed -i -e '/^# Epson Perfection 2450 /i# Any SCSI processor EPSON SCANNER...\nKERNEL=="sg[0-9]*", ATTRS{type}=="3", ATTRS{vendor}=="EPSON", ATTRS{model}=="SCANNER*", MODE="0664", GROUP="lp", ENV{libsane_matched}="yes"' tools/udev/libsane.rules
# Install the udev rules file:
install -m644 tools/udev/libsane.rules %{buildroot}%{_sysconfdir}/udev/rules.d/55-libsane.rules
# Service files:
# Sources 202 and 203 are files to enable socket based service activation which replaced xinetd
# Source202 is saned@.service and Source203 is saned.socket
# see https://bugzilla.opensuse.org/show_bug.cgi?id=1074054#c5
# and https://bugzilla.opensuse.org/attachment.cgi?id=760460
install -d -m755 %{buildroot}%{_unitdir}
install -m644 %{SOURCE202} %{buildroot}%{_unitdir}
install -m644 %{SOURCE203} %{buildroot}%{_unitdir}
# OpenSLP registration stuff:
install -d -m755 %{buildroot}%{_sysconfdir}/slp.reg.d
install -m644 %{SOURCE102} %{buildroot}%{_sysconfdir}/slp.reg.d
# Delete documentation files for non-Linux platforms:
rm %{buildroot}%{_defaultdocdir}/sane-backends/{README.aix,README.beos,README.darwin,README.djpeg,README.freebsd,README.hp-ux,README.netbsd,README.openbsd,README.os2,README.solaris,README.unixware2,README.unixware7,README.windows,README.zeta}
# Mark locale-dependent files with the respective 'lang' tag in the file list, see
# https://en.opensuse.org/openSUSE:Packaging_Conventions_RPM_Macros#.25find_lang
%find_lang sane-backends

%pre
if [ $1 = 2 ] ; then
    # In case of an upgrade the erroneously created as directories saned.socket and saned@.service
    # must be removed, otherwise the upgrade will fail,
    # see https://bugzilla.opensuse.org/show_bug.cgi?id=1074054#c5
    # and https://bugzilla.opensuse.org/attachment.cgi?id=760460
    if [ -d /usr/lib/systemd/system/saned.socket ] ; then
        /usr/bin/rmdir /usr/lib/systemd/system/saned.socket
    fi
    if [ -d /usr/lib/systemd/system/saned@.service ] ; then
        /usr/bin/rmdir /usr/lib/systemd/system/saned@.service
    fi
fi
%service_add_pre saned.socket

%post
/sbin/ldconfig
%service_add_post saned.socket

%preun
%service_del_preun saned.socket

%postun
/sbin/ldconfig
%service_del_postun saned.socket

%files -f sane-backends.lang
%defattr(-,root,root)
%dir %{_sysconfdir}/sane.d
%config(noreplace) %{_sysconfdir}/sane.d/*.conf
%dir %{_sysconfdir}/slp.reg.d
%config(noreplace) %{_sysconfdir}/slp.reg.d/*
%dir %{_sysconfdir}/udev
%dir %{_sysconfdir}/udev/rules.d
%{_sysconfdir}/udev/rules.d/55-libsane.rules
%{_sbindir}/saned
%{_bindir}/scanimage
%{_bindir}/sane-find-scanner
%{_bindir}/gamma4scanimage
%{_bindir}/umax_pp
%{_datadir}/sane/
%{_libdir}/libsane.so.*
%{_libdir}/sane/
%{_unitdir}/saned@.service
%{_unitdir}/saned.socket
#dir /var/lock/sane
%doc %{_defaultdocdir}/sane-backends/
%doc %{_mandir}/man1/scanimage.1.gz
%doc %{_mandir}/man1/sane-find-scanner.1.gz
%doc %{_mandir}/man1/gamma4scanimage.1.gz
%doc %{_mandir}/man5/sane-*.5.gz
%doc %{_mandir}/man7/sane.7.gz
%doc %{_mandir}/man8/saned.8.gz

%files devel
%defattr(-,root,root)
%{_bindir}/sane-config
%{_includedir}/sane/
%{_libdir}/libsane.so
%{_libdir}/pkgconfig/sane-backends.pc
%doc %{_mandir}/man1/sane-config.1.gz

%files autoconfig
%defattr(-,root,root)
%dir %{_sysconfdir}/udev
%dir %{_sysconfdir}/udev/rules.d
%{_sysconfdir}/udev/rules.d/56-sane-backends-autoconfig.rules

%changelog
* Wed Oct 14 2020 jsmeix@suse.de
- sane-backends version upgrade to 1.0.31 for SLE15:
  * sane-backends version upgrade to 1.0.30
    fixes memory corruption bugs CVE-2020-12861, CVE-2020-12862,
    CVE-2020-12863, CVE-2020-12864, CVE-2020-12865,
    CVE-2020-12866, CVE-2020-12867 (bsc#1172524)
    cf. the entry below dated "Tue Aug 18 15:15:05 UTC 2020"
  * sane-backends version upgrade to 1.0.31
    to further improve hardware enablement for scanner devices
    (jsc#SLE-15561 and jsc#SLE-15560 with jsc#ECO-2418)
  * The new sane-backends version requires additionally the
    libpoppler-glib8 RPM (because of the new escl backend)
    which is provided by the SLE15 Basesystem-Module.
* Wed Sep 23 2020 jsmeix@suse.de
- Upgraded to sane-backends version 1.0.31
  Changes since 1.0.30
  see https://gitlab.com/sane-project/backends/-/blob/master/NEWS
  Backends
  * adds the canon_lide70 backend
  * avision: adds support for the KODAK i1120,
    fixes thread cancellation issues,
    disables exposure option for non-filmscanners
  * canon_dr: improves error reporting
  * dmc: fixes compiler warnings on the scan area options
  * epsonds: rewrites the network I/O following changes
    made to the epson2 backend in 1.0.30 to fix security issues.
    Network support is still unsupported.
  * escl: adds ADF support, fixes many minor issues and improves
    error handling. Now also supports devices behind a proxy
    (needs explicit configuration).
  * fujitsu: adds support for the fi-800R and a card scanning
    slot, fixes a bug when reading hardware sensors on the first
    invocation. Adds USB IDs for fi-7800 and fi-7900.
  * genesys: adds support for the Canon 5600F, Canon LiDE 90,
    Plustek OpticFilm 7200 and 7200 (v2), 7400, 7600i, 8100
    and 8200i. Fixes several issues with the Canon 8600F.
    Adds 4800dpi support for the Canon LiDE 210 and fixes 3200dpi
    flatbed support on the Canon 8400F. Adds an option to fill
    dark calibration with a constant. Adds transparency support
    for gl847 chipset based devices. Fixes CIS scanner support
    for gl842 chipset based devices. Removes lineart and image
    enhancement emulation support.
  * gphoto: supports the PLANon DocuPen RC800 (with a recent
    enough version of gphoto2)
  * gt68xx: modifies scan cancellation behaviour
  * hp5400: adds button support, fixes a scan cancellation
    crash issue
  * pixma: add supports for the i-SENSYS MF440 Series and untested
    support for the PIXMMA G7000 Series and GM4000 Series as well
    as the i-SENSYS MF720 Series.
  * plustek: fixes a potential buffer overrun
  * test: adds gamma options
  Documentation
  * removes the SANE Standard. This is now maintained
    as a separate project at
    https://gitlab.com/sane-project/standard
    HTML and PDF versions can be found at
    https://sane-project.gitlab.io/standard/
  * adds and updates information for multiple supported and
    unsupported devices
  * translation updates for British English, French, German,
    Italian and Ukranian
  * scanimage: documents the JPEG compression level
  * minor improvements documenting build requirements
  Build
  * removes the --with-api-spec option from configure
  * replaces the --enable-avahi option with an --with-avahi
    that defaults to enabling if possible. If the option is given
    and the required support is not available, configure will
    exit with an error.
  * improves checking for libjpeg version dependent requirements
  * has been made reproducable (upstream issue 228)
  * fixes build issues on MinGW
  Miscellaneous
  * various fixes and improvements in the USB record/replay support
  * fixes a file descriptor validation test in sanei_pio
  * adds missing include in sanei_usb
- sane-backends.builttime.patch is no longer needed because the
  issue https://gitlab.com/sane-project/backends/-/issues/228
  is fixed in the upstream sources
* Tue Aug 18 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 1.0.30:
  * epson2: fixes CVE-2020-12867 (GHSL-2020-075) and several memory
    management issues found while addressing that CVE
  * epsonds: addresses out-of-bound memory access issues to fix
    CVE-2020-12862 (GHSL-2020-082) and CVE-2020-12863 (GHSL-2020-083),
    addresses a buffer overflow fixing CVE-2020-12865 (GHSL-2020-084)
    and disables network autodiscovery to mitigate CVE-2020-12866
    (GHSL-2020-079), CVE-2020-12861 (GHSL-2020-080) and CVE-2020-12864
    (GHSL-2020-081).  Note that this backend does not support network
    scanners to begin with.
  * magicolor: fixes a floating point exception and uninitialized data
    read
  * fixes an overflow in sanei_tcp_read()
* Thu Feb 20 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 1.0.29:
  * Backends
    + adds an escl backend (theoretically supporting all AirPrint
    devices with a scan unit)
    + adds support for 23 new scanner models via existing backends
    + significantly changes genesys and pixma backends
    + fixes bugs in canon_dr, fujitsu, hp3900, mustek_usb2,
    plustek and xerox_mfp backends
    + fixes all compiler warnings on Debian 10 (#120)
    + fixes portability issues for uClibc-ng and MacOS builds
    + adds support to record and replay USB I/O traffic
    + adds timestamps to debug logs
  * Frontends
    + fixes a 32-bit arithmetic overflow issue in scanimage
  * Documentation
    + updates translations for British English, Catalan, German,
    Ukrainian, Valencian
    + adds scangearmp2 external backend descriptions
    + updates hpaio and utsushi external backend descriptions
    + adds the ChangeLogs/ directory to the source tarball (#103)
  * Build
    + additionally requires libcurl and libxml2 to build the
    escl backend
    + requires libxml2 for USB I/O recording and replay
    functionality
    + re-enables pthread support for backends that use its API
    directly, irrespective of the pthread_t type (#153)
    + moves genesys and pixma backends to a directory of their own
- Update to 1.0.28:
  * Backends
    + adds a ricoh2 backend
    + adds support for 40+ new scanner models
    + significantly changes canon_dr, fujitsu, genesys, gt68xx,
    + hp5590 and, pixma backends
    + fixes bugs in as6e, avision, mustek and plustek backends
    + fixes scores of compiler warnings
  * Frontends
    + adds, changes and removes options for saned (see man 8 saned
    for details)
  - adds: -l (listen), -D (daemonize), -o (once),
  - e (stderr), -u (user)
  - removes: -s (syslog). Use -a -d level -o -f for the
    old behavior
  - changes: -d (debug). Use -a -d level -o -f -e for the
    old behavior
    + saned now cancels scans if the data connections appears to
    have gone away (after 4 seconds by default, configurable in
    saned.conf)
    + adds --output-file option to scanimage
    + adds --help option to scan-find-scanner
    + changes sane-desc to create relative hyperlinks
  * Documentation
    + adds translations for Catalan, Hebrew and Valencian
    + updates translations for British English, Dutch, German and
    + Ukrainian
    + marks unmaintained backends as such
    + documents USB workaround in sane-usb manual page
  * Build
    + requires a C++11 compatible compiler for the genesys backend
    + requires a JPEG library when building the pixma backend
    + fixes unneeded linking when not using preloadable backend
    support
    + disables pthread support for systems with non-integral
    pthread_t type
    + normalizes trailing whitespace in source code files. If you
    have local patches that no longer apply, have a look at the
    whitespace ignoring options of patch and git apply.
- Rebased patches:
  * sane-backends.builttime.patch
- Dropped patches:
  * no-descriptions-external-hpoj.patch
* Thu Apr 12 2018 jsmeix@suse.de
- Replaced the non-working saned@.service with the simpler kind
  according to the second template in "man saned" of the therein
  described "systemd configuration for saned" (boo#1074054).
* Wed Mar 21 2018 jsmeix@suse.de
- Drop BuildRequires for libieee1284-devel and libieee1284
  which is only needed for some parallel port scanners
  but parallel port scanners are no longer supported
  so that the backends canon_pp, hpsj5s, and mustek_pp
  are no longer provided.
- Fixed installation of systemd unit files saned@.service
  and saned.socket that enable socket based saned activation
  which replaces xinetd (boo#1074054).
* Sun Oct 29 2017 meissner@suse.com
- add a 32bit devel package for use in wine32 bit builds
* Fri Jun 16 2017 nmoudra@suse.com
- Deleted xinetd service in favor of socket based activation
  via systemd unit files saned@.service and saned.socket
  see https://build.opensuse.org/request/show/504186
* Wed May 24 2017 jsmeix@suse.de
- Upgraded to sane-backends version 1.0.27:
  There is no 1.0.26 release of sane-backends.
  That number was skipped so that the SANE upstream
  development version numbers would more clearly be
  an extension of the prior release.
  Changes since 1.0.25:
  * Significant enhancements to canon_dr, epjitsu, epsonds,
    fujitsu, genesys, hp3500, pixma and xerox-mfp backends.
  * Minor updates, bugfixes or scanners added in several backends.
  * 30+ new scanner models supported.
  * Made libusb-1.0 the default for USB support.
  * Switched code from C90 to C99 (Thanks to Volker Diels-Grabsch).
  * Updated Linux USB3 workaround:
    The Linux USB3 workaround which was added in version 1.0.25
    is now disabled by default. If you have difficulty using
    a scanner which previously worked, or intermittent scanner
    availability, try setting the new environment variable
    SANE_USB_WORKAROUND=1
    before starting your frontend.
  * Documentation and translation updates.
  * Bugfixes (Avahi, threading, USB, ICC/PNG/JPEG, etc).
  * Reduced compiler warnings, improved code:
    A special thanks goes to Olaf Meeuwissen for picking up
    the janitorial duties in sane-backends. He has found and
    fixed a large number of long-standing bugs, curated the
    SANE upstream bug tracker, improved the build scripts
    and docs, and provided user support.
- CVE-2017-6318.patch is no longer needed because
  the issue is fixed in the upstream sources.
- dell1600n_net-fix-strncat.patch is no longer needed because
  the issue is fixed in the upstream sources.
* Tue Feb 28 2017 jsmeix@suse.de
- CVE-2017-6318.patch fixes CVE-2017-6318 which is about that via
  access to saned some opcodes could leak uninitialized memory
  back to the requester allowing information disclosure
  of memory content in saned (bsc#1027197).
  In general regarding "access to saned" see
  https://en.opensuse.org/SDB:CUPS_and_SANE_Firewall_settings
* Mon Jan 11 2016 olaf@aepfle.de
- sane-backends.builttime.patch: reduce build-compare noise
* Wed Dec 30 2015 stefan.bruens@rwth-aachen.de
- remove gphoto2 backend, as is usefulness is highly questionable,
  but adds many (indirect) build and runtime dependencies
* Tue Oct  6 2015 jsmeix@suse.de
- Upgraded to sane-backends version 1.0.25:
  Changes since 1.0.24:
  * New backends: epsonds (Epson DS, PX and WF series),
    pieusb (PIE and Reflecta film/slide scanners).
  * Support for JPG and PNG output format in scanimage.
  * Significant enhancements to avision, canon_dr, epjitsu,
    fujitsu, genesys, kodakaio and pixma backends.
  * Minor updates, bugfixes or scanners added in several backends.
  * 300 new scanner models supported.
  * Workaround for USB3 problems in Linux kernel.
  * Added code for IR functionality.
  * Documentation and translation updates.
  * Bugfixes (threading, networking, udev rules).
  A big thanks to Olaf Meeuwissen, for his efforts in bug triage,
  patch wrangling and code cleanups.
- fix-buffer-overflow.patch, fix-mustek_pp_ccd300.c.patch,
  install-umax_pp-tool.patch, MG5550-works.patch are obsolete
  since sane-backends-1.0.24 because it is fixed in the source.
- re-add-SANE_CAP_ALWAYS_SETTABLE.patch should be longer needed
  because there should be longer a fontend that references
  SANE_CAP_ALWAYS_SETTABLE in its source code.
- Recreated adapt_epkowa.desc_for_yast2-scanner.patch
  according to the comment in sane-backends.spec
  so that it applies for sane-backends-1.0.25.
- Dropped avision.c.patch and avision.conf.patch
  (cf. the entry below dated "Mon Sep 15 23:23:23 UTC 2013")
  because it does no longer apply to sane-backends-1.0.25 sources.
  Issues that are not specific for a particular Linux distribution
  must be fixed directly at SANE upstream so that all Linux
  distributions get it properly fixed and not via patches
  at one particular Linux distribution where it falls apart
  each time when SANE upstream changes that sources.
- Added BuildRequires for libpng-devel and libtiff-devel because
  scanimage output format supports PNG and TIFF.
- dell1600n_net-fix-strncat.patch fixes the following build error:
  Statement might be overflowing a buffer in strncat.
  BAD: strncat(buffer,charptr,sizeof(buffer)) is wrong
  GOOD: strncat(buffer,charptr,sizeof(buffer)-strlen(buffer)-1)
  The upstream issue report is
  https://alioth.debian.org/tracker/index.php?func=detail&aid=315198&group_id=30186&atid=410366
- Disabled use of LaTeX to generate documentation because LaTeX
  blows up the build system and "BuildRequires: texlive-latex"
  causes various cycles and the sane.ps documentation
  is not for users but for developers who could get
  the "Programmer's Documentation" from SANE upstream
  at http://www.sane-project.org/docs.html
* Wed Jan 14 2015 johannes@lst.de
- MG5550-works.patch: support Canon Pixma MG5500
* Tue Dec  3 2013 jsmeix@suse.de
- Upgraded to sane-backends version 1.0.24:
  Changes since 1.0.23:
  * Significant enhancements to pixma, genesys, kodakaio,
    fujitsu, canon_dr.
  * Minor updates, bugfixes or scanners added in several backends.
  * Added new testsuite.
  * 51 new scanner models supported.
  * USB support improvements.
  * Improved build system (mingw64, bug fixes,
    default pthread on Linux).
  * Documentation updates.
  * Bugfixes.
  For Details see the ChangeLog file.
- sane-backends-1.0.21-SCX4500W.patch that adds usb id for SCX4500W
  is obsolete since sane-backends-1.0.24 because it is fixed
  in the source.
- fix-no-return-in-nonvoid-function.patch that fixes a
  "control reaches end of non-void function" gcc warning
  in kodakaio.c is obsolete since sane-backends-1.0.24
  because it is fixed in the source.
- Recreated adapt_epkowa.desc_for_yast2-scanner.patch
  according to the comment in sane-backends.spec
  so that it applies for sane-backends-1.0.24.
* Mon Sep 16 2013 piny@gmx.com
- Workaround for hp scanjet 8200: As described in
  https://bugzilla.novell.com/show_bug.cgi?id=840443
  when operating on a hp scanjet 8200 the avision driver gets stuck
  in a loop trying to detect an ADF, even if none is present.
  In order circumvent this issue, following workaround has been
  implemented:
  1) create an option "enforce-no-adf" in the file avision.conf
  2) patch the code in avision.c to make use of this option,
    if the conditions that lead to the unsuccessful ADF search
    (namely detection of NO ADF but reporting of SOME ADF type)
    is given.
  Per default the new option is inactive by comment.
  Activate at your own risk!
  An upstream report was added to
  https://alioth.debian.org/tracker/index.php?func=detail&aid=314108&group_id=30186&atid=410366
- created patch110 (avision.conf.patch) for avision.conf
- created patch111 (avision.c.patch) for avision.c
* Thu Apr  4 2013 meissner@suse.com
- fixed /etc/slp.reg.d/ ownership conflict, just have
  it as %%dir and the files as %%config.
  (see OBS RQ 162582 decline message)
* Wed Mar  6 2013 coolo@suse.com
- update license to new format
* Sat Jan 19 2013 lnussel@suse.de
- require libv4l-devel to enable v4l backend
* Tue Dec 11 2012 jsmeix@suse.de
- Our own special source file epkowa.desc is dropped because
  the package iscan-free is dropped (bnc#788756). Instead
  adapt_epkowa.desc_for_yast2-scanner.patch adapts the upstream
  epkowa.desc for yast2-scanner which works without additional
  adaptions in yast2-scanner so that the sane-backends package
  works on released openSUSE systems without a RPM requirement
  for a yast2-scanner update (bnc#788756 starting at comment#14).
* Tue Oct 16 2012 jsmeix@suse.de
- Upgraded to sane-backends version 1.0.23:
  New backends:
  kvs40xx (Panasonic KV-S40xx), kodakaio (Kodak AiO ESP and Hero).
  Significant enhancements to several backends.
  30 new scanner models supported.
  V4L support improvements.
  Improvements for builds on multiple platforms.
  Improved udev rules.
  Updated software deskew algorithm.
  Documentation updates.
  Bugfixes.
  Note:
  This is one more release of the SANE 1.0 series, compare
  the below entry dated "Thu Feb 28 13:56:15 CET 2008".
- sane-backends-1.0.22-xerox_mfp-fix-usb-devices.patch that
  fixes usb device support in xerox_mfp is obsolete since
  sane-backends-1.0.23 because it is fixed in the source.
- fix-no-return-in-nonvoid-function.patch fixes a "control reaches
  end of non-void function" gcc warning which lets build fail
  with "no-return-in-nonvoid-function" error in kodakaio.c.
* Thu Aug 23 2012 cfarrell@suse.com
- license update: GPL-2.0+ and SUSE-GPL-2.0+-with-sane-exception and
  SUSE-Public-Domain
  The LICENSE file in the sane-backends packages explains the licensing of
  the package. Added SUSE-GPL-2.0+-with-sane-exception to the spreadsheet
  linked from license.opensuse.org as that license is not yet upstream at
  http://www.spdx.org/licenses (hence the SUSE- proprietary extension)
* Fri Apr 20 2012 jsmeix@suse.de
- Configure --enable-libusb_1_0 plus BuildRequires libusb-1_0-devel
  to use libusb1 (instead of using libusb0 via libusb-compat),
  see https://bugzilla.novell.com/show_bug.cgi?id=559697#c7
  for the libusb versioning numbering.
- Use traditional bash scriptlets for post/postun with
  an explicite "exit 0" line at the end to be fail safe
  and therefore also "PreReq: /sbin/ldconfig" explicitly,
  see the "Shared_libraries" section in
  http://en.opensuse.org/openSUSE:Packaging_scriptlet_snippets
- BuildIgnore ghostscript-x11 because BuildRequires texlive-latex
  is needed for sane.tex -> sane.dvi -> sane.ps but texlive-latex
  requires texlive which requires ghostscript-x11 but the latter
  is not needed and blows up the build system.
- Minor cleanups in the spec file.
* Tue Mar 20 2012 jslaby@suse.de
- added explicit "BuildRequires libusb-compat-devel" to
  re-add support for USB scanners
* Sun Feb  5 2012 lnussel@suse.de
- sane-backends-1.0.21-SCX4500W.patch adds usb id for SCX4500W
- sane-backends-1.0.22-xerox_mfp-fix-usb-devices.patch fixes
  usb device handling regression in xerox_mfp (bnc#745245)
* Sun Nov 20 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Thu Sep 29 2011 jsmeix@suse.de
- Added an entry for "SCSI processor EPSON Perfection1640"
  to libsane.rules (bnc#681146) see in particular
  https://bugzilla.novell.com/show_bug.cgi?id=681146#c43
- Added a wildcard entry for any "SCSI processor EPSON SCANNER*"
  to libsane.rules see the "55-libsane.rules"/"Device recognition"
  mail thread in June 2011 on sane-devel@lists.alioth.debian.org
* Tue Mar 29 2011 jsmeix@suse.de
- Fixed udev rules for SCSI scanners:
  For SCSI scanners "ATTRS" is mandatory for every sysfs attribute
  (in particular ATTRS{type}, ATTRS{vendor}, and ATTRS{model})
  so that "ATTRS" is replaced by "ATTR" only for USB scanners
  (see openSUSE/Novell Bugzilla bnc#681146).
* Fri Mar 25 2011 jsmeix@suse.de
- Fixed udev rules for SCSI scanners:
  Because of openSUSE/Novell Bugzilla bnc#436085
  (see the entry below dated "Tue Oct 21 13:12:42 CEST 2008")
  "SYSFS" and "ATTRS" were replaced by "ATTR" everywhere in
  libsane.rules but for SCSI scanners "ATTRS{type}" is mandatory
  (see openSUSE/Novell Bugzilla bnc#681146).
* Sun Feb 20 2011 coolo@novell.com
- fix dependencies of devel package
* Wed Feb 16 2011 jsmeix@suse.de
- Upgraded to sane-backends version 1.0.22:
  New backends:
  kvs20xx (Panasonic KV-S20xx), magicolor (Konica-Minolta).
  Significant enhancements to several backends.
  More than 80 new scanner models supported.
  Support many more networked scanners.
  Added -A option to scanimage.
  Improved build system.
  Improved USB support.
  Improved udev rules.
  Documentation updates.
  Bugfixes.
  Note:
  This is one more release of the SANE 1.0 series, compare
  the below entry dated "Thu Feb 28 13:56:15 CET 2008".
- sane-backends-1.0.21-i18n.patch,
  fix-genesys-create_range-type.patch,
  fix-xerox_mfp-color-mode.patch, and
  canon-backend-autoprobing.patch are obsolete since
  sane-backends-1.0.22 because it is fixed in the source.
- Adapted how we derive our libsane.rules file from the
  generated one which uses now "ATTRS" (instead of "SYSFS"),
  see the below entry dated "Tue Oct 21 13:12:42 CEST 2008".
- Updated models.dat to the one from the current HPLIP 3.11.1.
- Added only those new models from epkowa.desc in the
  sane-backends 1.0.22 sources which 'requires DFSG non-free'
  plugin software to our epkowa.desc source file so that the
  supported models in our epkowa.desc source file still match
  to what is supported by our iscan-free package but more users
  of models which require the proprietary software from Avasys
  will be informed via yast2-scanner.
* Thu Dec  9 2010 jsmeix@suse.de
- fix-xerox_mfp-color-mode.patch adds SANE_VALUE_SCAN_MODE_HALFTONE
  in xerox_mfp.c to fix a regression in sane-backends-1.0.21
  where the xerox_mfp works only in grayscale mode
  (see openSUSE/Novell Bugzilla bnc#658017).
- Updated models.dat to the one from the current hplip-3.10.9.
* Wed Sep 22 2010 jsmeix@suse.de
- Configure with --enable-pthread so that backends can use
  POSIX threads to implement asynchronous I/O instead of
  the default which uses a pipe and forks a reader process
  (see openSUSE/Novell Bugzilla bnc#633780).
* Wed Sep 15 2010 aj@suse.de
- BuildRequires libieee1284-devel.
- Split up devel package.
* Tue Jun 22 2010 jsmeix@suse.de
- Updated models.dat to the one from our current HPLIP version
  so that the generated hpaio.desc matches to our HPLIP version.
- Enhanced epkowa.desc only with models which require proprietary
  software so that the supported models in epkowa.desc
  still match to what is supported by our iscan-free package
  but more users of models which require proprietary
  software will be informed via yast2-scanner.
* Tue May 11 2010 lnussel@suse.de
- remove disable-resmgr-support.patch.
  It's not needed as configure won't find resmgr anyways
  (see Novell/Suse Bugzilla bnc#605914).
* Fri May  7 2010 jsmeix@suse.de
- Upgraded to sane-backends version 1.0.21:
  New backends:
  kodak (Kodak i18xx), kvs1025 (Panasonic KV-S10xx),
  p5 (Primax PagePartner)
  Many backends updated.
  224 more scanner models supported.
  More consistent option naming.
  Scanimage no longer writes image to tty.
  Modern translation infrastructure.
  Improved saned network daemon.
  Internal SCSI, USB, threading, TCP & UDP code updates.
  Updated HAL and udev support.
  New sanei_magic image processing library.
  Documentation updates.
  Bugfixes.
  Note:
  This is one more release of the SANE 1.0 series, compare
  the below entry dated "Thu Feb 28 13:56:15 CET 2008".
- fix-hp3900_config.c.patch, sane-desc_closedir.patch,
  fix-lexmark_low-memory-leak.patch, and
  fix-hp3900_sane-string-option-sizes.diff are obsolete since
  sane-backends-1.0.21 because it is fixed in the source.
- sane-backends-1.0.20-xerox_mfp.diff backported post 1.0.20
  xerox_mfp changes and is therefore removed since
  sane-backends-1.0.21 which contains those changes, compare
  the below entry dated "Thu Oct  8 09:35:17 UTC 2009".
- Slightly adapted disable-resmgr-support.patch and
  no-descriptions-external-hpoj.patch to apply to the
  sane-backends-1.0.21 sources.
- fix-genesys-create_range-type.patch lets in genesys.c
  the create_range function be of type 'SANE_Range *'
  to fix 'assignment makes pointer from integer' bugs
  wherever the create_range function is called.
* Wed Apr 28 2010 jsmeix@suse.de
- HAL is deprecated and does no longer support to grant read/write
  device access permissions for scanners to the currently logged
  in "desktop" user. Therefore all HAL related stuff was removed
  (see Novell/Suse Bugzilla bnc#593946).
- Removed /usr/lib[64]/libsane.la
  (see Novell/Suse Bugzilla bnc#592143).
* Mon Feb  1 2010 jengelh@medozas.de
- package baselibs.conf
* Fri Dec 18 2009 seife@opensuse.org
- fix udev warnings 'NAME="%%k" is superfluous'
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Thu Oct  8 2009 lnussel@suse.de
- backport xerox_mfp changes to support samsung printers
* Wed Sep 30 2009 jsmeix@suse.de
- fix-lexmark_low-memory-leak.patch adds a missing call to free
  in sanei_lexmark_low_find_start_line in backend/lexmark_low.c
  (see Novell/Suse Bugzilla bnc#542341).
- fix-hp3900_sane-string-option-sizes.diff fixes option sizes
  because otherwise the frontend (e.g. xsane) may crash
  (see Novell/Suse Bugzilla bnc#535752).
* Fri Sep 18 2009 jsmeix@suse.de
- Updated models.dat with the one in the HPLIP 3.9.8 sources and
  adapted create_hpaio.desc_from_models.dat accordingly so that
  it results a hpaio.desc scanner description file for SANE
  which matches to the sacnner models which are supported
  by our currently provided HPLIP version.
* Thu Sep 17 2009 crrodriguez@suse.de
- use find_lang macro
- run ldconfig correctly
* Thu Aug 13 2009 jsmeix@suse.de
- sane-desc_closedir.patch adds a missing call to closedir
  to sane-desc.c (see Novell/Suse Bugzilla bnc#530313).
* Wed Jul 29 2009 jsmeix@suse.de
- fix-hp3900_config.c.patch fixes a possible for loop overflow
  in hp3900_config.c (see Novell/Suse Bugzilla bnc#517281).
- fix-mustek_pp_ccd300.c.patch fixes undefined operations
  in mustek_pp_ccd300.c (see Novell/Suse Bugzilla bnc#498435).
* Fri Jun 12 2009 jsmeix@suse.de
- re-add-SANE_CAP_ALWAYS_SETTABLE.patch re-adds
  SANE_CAP_ALWAYS_SETTABLE to sane.h which was erroneously
  removed in sane-backends-1.0.20 so that sane-frontends
  and xsane can no longer build,
  see http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=527675
* Wed Jun 10 2009 jsmeix@suse.de
- Upgraded to sane-backends version 1.0.20:
  New backends:
  canon_dr (Canon DR-series), coolscan3 (Nikon LS & Coolscan),
  rts8891 (Umax & HP 44xx), xerox_mfp (Samsung/Xerox/Dell MFPs)
  Many backends updated.
  75 more scanner models supported.
  New (automake compatible) build system.
  Avahi support.
  More network scanners supported.
  Epson backend deprecated, use epson2.
  Coolscan2 backend deprecated, use coolscan3.
  Internal SCSI, USB, threading, TCP & UDP code updates.
  Updated HAL and udev support.
  Improved saned configuration.
  Scanimage updates.
  Updated translations.
  Documentation updates.
  Bugfixes.
  Note:
  This is one more release of the SANE 1.0 series, compare
  the below entry dated "Thu Feb 28 13:56:15 CET 2008".
- Re-enabled "autoreconf -fi" in the build section (it was
  disabled because it failed for sane-backends-1.0.19).
- fix-uninitialized-variables.patch and
  fix-sanei_scsi_find_devices.patch are obsolete since
  sane-backends-1.0.20 because it is fixed in the source.
- Adapted install-umax_pp-tool.patch for the new build system
  (now tools/Makefile.am instead of tools/Makefile.in).
- no-descriptions-external-hpoj.patch removes
  descriptions-external/hpoj.desc from doc/Makefile.am
  because it is intentionally removed from the sources
  in the prep section to avoid confusion with its successor
  hpaio.desc (since openSUSE 10.3 the package hp-officeJet
  which provided the hpoj driver is dropped).
* Fri Jan 23 2009 jsmeix@suse.de
- Do no longer add a generic entry for SCSI scanners
  to the HAL fdi file 70-scanner.fdi because this
  is now provided by the hal package itself
  (see Novell/Suse Bugzilla bnc#462639 comment #29).
* Fri Jan 16 2009 jsmeix@suse.de
- Avoid to suppress falsely found as "unsupported" models
  in 55-libsane.rules and in 70-scanner.fdi
  (see Novell/Suse Bugzilla bnc#439193 starting at comment #6).
- Avoid to get changed sources packaged into our source RPM
  (see Novell/Suse Bugzilla bnc#463464 comment #11).
* Tue Jan 13 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Wed Dec  3 2008 lnussel@suse.de
- use "usb" instead of "usb_device" (bnc#438867)
* Wed Dec  3 2008 jsmeix@suse.de
- Moved /etc/hal/fdi/policy/10osvendor/70-scanner.fdi
  to /usr/share/hal/fdi/information/20thirdparty/70-scanner.fdi
  (see Novell/Suse Bugzilla bnc#438867).
* Tue Nov 18 2008 jsmeix@suse.de
- In /etc/hal/fdi/policy/10osvendor/70-scanner.fdi
  disable entries for USB scanners which are "unsupported"
  (see Novell/Suse Bugzilla bnc#444158).
* Wed Oct 29 2008 jsmeix@suse.de
- Having only models in /etc/udev/rules.d/55-libsane.rules which
  are in /etc/udev/rules.d/56-sane-backends-autoconfig.rules
  is too restrictive because libsane.rules disables
  USB autosuspend in the kernel which is needed as safe default
  for any scanner regardless of its support status.
  The only valid exception are unsupported models.
  Therefore the scanner database is now created directly
  in the spec file with the file name "scanner.database"
  so that the scanner database can also be used to determine
  the "unsupported" models to be disabled in libsane.rules
  (see Novell/Suse Bugzilla bnc#439193).
* Tue Oct 28 2008 jsmeix@suse.de
- install-umax_pp-tool.patch installs tools/umax_pp as
  /usr/bin/umax_pp which is built but not installed
  but it is needed to recover from a failed scan
  with scanners which use the umax_pp backend
  (see the Debian report http://bugs.debian.org/496833).
* Tue Oct 28 2008 jsmeix@suse.de
- Avoid false positives (e.g. unsupported) and problematic
  models in /etc/udev/rules.d/55-libsane.rules by having
  all model entries disabled where the support status is
  not "complete" or "good", i.e. when it is not listed
  in /etc/udev/rules.d/56-sane-backends-autoconfig.rules
  (see Novell/Suse Bugzilla bnc#439193).
* Tue Oct 21 2008 jsmeix@suse.de
- Changed /etc/udev/rules.d/55-libsane.rules to jump to the end
  if SUBSYSTEM!="usb" and replaced SYSFS by ATTR and did
  the same chages in create_sane-backends-autoconfig.rules
  (see Novell/Suse Bugzilla bnc#436085).
* Thu May 15 2008 jsmeix@suse.de
- Changed create_sane-backends-autoconfig.rules
  to output '$$' insead of '$' because in udev rules files
  '$$' represents the '$' character itself, see "man udev"
  (see Novell/Suse Bugzilla bnc#390783).
* Thu Apr 17 2008 jsmeix@suse.de
- Use info.subsystem instead of the deprecated info.bus
  for the HAL 70-scanner.fdi file.
- Changed create_sane-backends-autoconfig.rules to ignore
  the INTERFACE field because it could be empty or arbitrary
  stuff like "Parport USB" or "SCSI USB IEEE-1394".
* Fri Apr 11 2008 jsmeix@suse.de
- Updated epkowa.desc from the current Iscan version 2.10.0.1.
- Replaced hpaio.desc which is currently messed up in HPLIP
  by create_hpaio.desc_from_models.dat which creates hpaio.desc
  directly from the models.dat file from HPLIP version 2.8.4.
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Tue Apr  8 2008 jsmeix@suse.de
- fix-sanei_scsi_find_devices.patch lets sanei_scsi_find_devices
  continue on to look at subsequent devices if the attach callback
  returns anything other than SANE_STATUS_GOOD
  (see Novell/Suse Bugzilla bnc#350688).
* Tue Mar 18 2008 jsmeix@suse.de
- Added "Supplements: sane-backends" to sane-backends-autoconfig
  sub-package.
* Thu Mar 13 2008 jsmeix@suse.de
- Added "scanner autoconfiguration" support via
  create_scanner_database, create_sane-backends-autoconfig.rules
  which create /etc/udev/rules.d/56-sane-backends-autoconfig.rules
  and provide it in the new sane-backends-autoconfig sub-package
  (see Novell/Suse Bugzilla bnc#347943).
* Tue Mar 11 2008 jsmeix@suse.de
- Replaced "scanner" by "SCSIviaUSBscanner" in info.capabilities
  in 70-scanner.fdi to explicitely mark those special USB scanners
  which do not use libusb but an unusual SCSI protocol which is a
  derivative of usb storage (see Novell/Suse Bugzilla bnc#341565).
* Thu Feb 28 2008 jsmeix@suse.de
- Updated to sane-backends version 1.0.19:
  New backends:
  cardscan (Corex Cardscan 800c), epjitsu (Epson-based Fujitsu),
  epson2 (various Epson scanners), hp3900 (HP ScanJet 3970 and
  more), hp5590 (HP ScanJet 5590 and more), hpljm1005 (HP LaserJet
  M1005 and more), hs2p (Ricoh IS400 series)
  Updated backends:
  abaton, agfafocus, apple, artec, artec_eplus48u, as6e, avision,
  canon, coolscan, coolscan2, dc25, dell1600n_net, dll, epson,
  fujitsu, genesys, gt68xx, hp3500, ibm, lexmark, microtek,
  microtek2, mustek, nec, net, pie, pint, pixma, plustek,
  plustek_pp, ricoh, s9036, sm3600, sm3840, snapscan, sp15c,
  st400, tamarack, teco2, test, u12, umax, umax1220u, umax_pp
  Plus:
  Scanimage detects more chipsets.
  Internal scsi, usb, tcp and udp code updates.
  Basic HAL .fdi creation support
  Build system updates.
  Updated translations.
  Documentation updates.
  Bugfixes.
  Note:
  This will be (hopefully) the last release of the SANE 1.0 series.
  The next release will be extended (in a backwards compatible
  fashion) to support more features of modern scanners.
- sane-backends-1.0.16-nb.patch (did locale rename: no -> nb)
  is obsolete since version 1.0.19 because it uses already 'nb'.
- in fix-buffer-overflow.patch the overflows in backend/epson.c
  backend/as6e.c and sanei/sanei_ab306.c are obsolete because
  they are fixed in the source (only backend/niash.c is left).
- replace-HZ-by-sysconf_SC_CLK_TCK.patch is obsolete because
  it is fixed in the source.
- fujitsu-disable-hw_ink_remain.patch is obsolete because
  it is fixed in the source.
- in fix-uninitialized-variables.patch the fix regarding
  teco2.c is obsolete because it is fixed in the source
  but a new fix regarding avision.c was added.
- fix-ambiguous-post-pre-increment.patch is obsolete because
  it is fixed in the source.
- module-build.diff is dropped because there is no reason to build
  driver modules as libtool modules and furthermore it makes our
  package incompatible with the rest of the SANE world.
- Since version 1.0.19 there is udev and HAL support.
  Therefore the old/outdated hotplug stuff (libsane.usermap
  and libusbscanner) is dropped (it was never used by openSUSE).
  Also the evil-hack init-script "sane-dev" is no longer provided.
  libsane.rules.CVS-2007-07-29.using-lp is obsolete because
  the udev rules file 55-libsane.rules is directly derived
  from tools/udev/libsane.rules.
  create_hal_global_fdi_from_libsane.rules is obsolete because
  the HAL fdi file 70-scanner.fdi is directly derived
  from tools/hal/libsane.fdi.
* Thu Jan 31 2008 adrian@suse.de
- Call create_hal_global_fdi_from_libsane.rules via bash.
  We can not rely on source file permissions
* Tue Aug 14 2007 jsmeix@suse.de
- Replaced create_hal_global_fdi_for_scanners by
  create_hal_global_fdi_from_libsane.rules which creates the
  global HAL 70-scanner.fdi file during build-time from the
  libsane.rules file (see Novell/Suse Bugzilla bnc#298878).
* Fri Aug 10 2007 jsmeix@suse.de
- Removed hpoj.desc completely to avoid confusion with its
  successor hpaio.desc because since openSUSE 10.3 the package
  hp-officeJet (for hpoj.desc) is dropped.
- Updated hpaio.desc from the current HPLIP version 2.7.7.
- Updated epkowa.desc from the current Iscan version 2.8.0.1.
* Fri Aug  3 2007 jsmeix@suse.de
- Added libsane.rules.CVS-2007-07-29.using-lp which are udev rules
  that are needed for the openSUSE 10.3 kernel. The rules are
  derived from what sane-desc in sane-backends 1.0.18-cvs creates.
* Wed Jun 13 2007 jsmeix@suse.de
- Adapted create_hal_global_fdi_for_scanners according to the
  currently newest changes in HAL (see Suse Bugzilla bnc#250659).
* Wed Jun  6 2007 dmueller@suse.de
- module-build.diff builds driver modules as libtool modules.
* Sat Apr 21 2007 aj@suse.de
- Use texlive.
* Wed Feb 21 2007 jsmeix@suse.de
- Added a fix for an "array subscript is above array bounds"
  error in niash.c to fix-buffer-overflow.patch
  (see Suse Bugzilla bnc#246654).
* Wed Jan 31 2007 jsmeix@suse.de
- Added a fix for an "array subscript is above array bounds"
  error in sanei_ab306.c to fix-buffer-overflow.patch
  (see Suse Bugzilla bnc#239953).
* Mon Jan 29 2007 jsmeix@suse.de
- Renamed the package from 'sane' (which is only used by Suse)
  to 'sane-backends' which is used by the rest of the world
  and let this package provide and obsolete 'sane'.
- Updated replace-HZ-by-sysconf_SC_CLK_TCK.patch to what
  there will be done upstream.
* Fri Dec  8 2006 jsmeix@suse.de
- fix-ambiguous-post-pre-increment.patch fixes an ambiguous
  post-increment in canon-sane.c for big-endian architectures
  (e.g. PowerPC).
* Fri Oct 27 2006 jsmeix@suse.de
- Updated hpaio.desc from the current HPLIP version 1.6.10
- Updated epkowa.desc from the current Iscan version 2.3.0.1.
- Added fixes of possible strncat buffer overflows and
  strncpy unterminated string errors in as6e.c
  to fix-buffer-overflow.patch.
- Replaced the complicated postinstall script by calling
  create_hal_global_fdi_for_scanners which should obsolete
  sane-dev (see Suse Bugzilla bnc#160899).
- Moved sane-dev from {_initrddir} to {_datadir}/sane/ to have it
  still available in case of backward compatibility problems.
* Sun Oct 22 2006 meissner@suse.de
- buildrequires libgphoto2-devel.
* Mon Sep 18 2006 jsmeix@suse.de
- fix-uninitialized-variables.patch fixes an uninitialized
  variable in teco2.c (see Suse Bugzilla bnc#205451).
- create_hal_global_fdi_for_scanners can be called by HAL or YaST
  to create a global HAL fdi file for scanners which are known
  by the current SANE version (see Suse Bugzilla bnc#160899).
* Mon Sep 11 2006 jsmeix@suse.de
- disable-resmgr-support.patch disables the resmgr support in SANE
  which is no longer needed in SANE because resmgr works now
  outside of SANE via ACLs for the scanner device nodes.
* Mon Sep  4 2006 jsmeix@suse.de
- Replaced the fix from Thu Aug 31 in fujitsu.c by a new fix
  fujitsu-disable-hw_ink_remain.patch which disables hw_ink_remain
  which causes a buffer overflow (see Suse Bugzilla bnc#202243).
* Thu Aug 31 2006 jsmeix@suse.de
- Added a fix of a too small char array in fujitsu.c to
  fix-buffer-overflow.patch (see Suse Bugzilla bnc#202243).
* Fri Jul 21 2006 jsmeix@suse.de
- canon-backend-autoprobing.patch lets the "canon" backend
  do scanner auto-recognition (see Suse Bugzilla bnc#177492).
* Tue Jul  4 2006 jsmeix@suse.de
- Updated to sane-backends version 1.0.18:
  New backends: dell1600n_net, hp3500, pixma, stv680.
  Updated backends: avision, canon, dll, epson, fujitsu, genesys,
  gt68xx, microtek2, mustek_pp, niash, plustek, snapscan, sp15c,
  test, u12, umax1220u.
  Several bug fixes.
- fix-buffer-overflow.patch fixes a too small char array
  which causes a buffer overflow if SANE_DEBUG_EPSON is set.
- replace-HZ-by-sysconf_SC_CLK_TCK.patch replaces the fixed HZ
  compile-time value (no longer supported by new glibc)
  by the more correct sysconf(_SC_CLK_TCK) runtime value.
- Updated hpaio.desc from the current HPLIP version 1.6.6a.
- Updated epkowa.desc from the current Iscan version 2.1.0.1.
* Wed Mar 22 2006 jsmeix@suse.de
- Added "haldaemon" to Should-Start in /etc/init.d/sane-dev and
  keeping old name "hal" for the same boot facility to be safe.
* Wed Mar 15 2006 jsmeix@suse.de
- Fixed percent-characters for RPM in post-install script
  (use '%%%%%%%%' in spec file to get actually '%%%%' in the script).
* Mon Mar 13 2006 jsmeix@suse.de
- Added automagic but safe pos-install script which tries
  to update resmgr permissions for scanners for an update
  from Suse Linux 10.0 to 10.1 (see Suse Bugzilla bnc#157055).
* Fri Jan 27 2006 jsmeix@suse.de
- Current epkowa.desc from the current iscan package.
- Current hpaio.desc made from the current hplip package.
- Changed hpoj.desc to match better to hpaio.desc.
  Added "hpoj is outdated" comments to hpoj.desc.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan  3 2006 jsmeix@suse.de
- Updated to sane-backends version 1.0.17.
* Mon Sep 26 2005 jsmeix@suse.de
- Disabled locking because /var/lock/sane/ would be world writable.
* Tue Sep 20 2005 jsmeix@suse.de
- Updated to sane-backends version 1.0.16.
* Mon Aug 22 2005 jsmeix@suse.de
- Updated the hpaio.desc file according to our current HPLIP
  software version 0.9.4.
* Tue Aug  9 2005 jsmeix@suse.de
- Updated the epkowa.desc in this package with the newest version
  from the iscan package to build the SANE documentation files
  accordingly (see the entry dated Thu Feb 17 16:52:24 CET 2005).
* Mon Aug  1 2005 jsmeix@suse.de
- Added the USB usermap file to the sane package to have the
  USB manufacturer and model IDs available for scanner detection.
* Wed May 25 2005 jsmeix@suse.de
- Added "Should-Start: hal" to sane-dev.
- The "SnapScan 1236u" needs no firmware upload (SUSE bug 73960).
* Tue May 17 2005 jsmeix@suse.de
- Fix "... is used uninitialized ..." warnings.
* Fri Mar 11 2005 jsmeix@suse.de
- Removed the obsolete SLP stuff from sane-dev
  because sane-dev has nothing to do with
  saned and its SLP registration (SUSE bug 72156).
- Using only SANE device entries in sane-dev which start
  with '^/dev/' to find possible SCSI devices because e.g.
  HPLIP creates SANE devices like 'hpaio:.../dev/...'.
- Replaced the test with 'ps' for a running scanimage
  with a simpler test using '/proc/$scanimagePID/cmdline'.
* Thu Feb 24 2005 jsmeix@suse.de
- Increased the maximum wait time in sane-dev to 30 seconds
  because some scanners fall asleep and need a longer time
  to wake up and respond to 'scanimage -f ...'.
* Thu Feb 17 2005 jsmeix@suse.de
- Updated the SUSE versions of the descriptions-external files.
- Now the SUSE versions of the descriptions-external files
  are used for build so that the SANE documentation files
  _defaultdocdir/sane/sane-backends/*.html
  are built accordingly.
- Added 'Provides: sane-backends' because the rest of the world has
  package names 'sane-backends' and 'sane-frontends' according to
  the two SANE software projecs. Therefore third party RPMs which
  require SANE libraries usually have 'Requires: sane-backends'.
* Thu Feb 10 2005 ro@suse.de
- added libpng to neededforbuild (for tetex)
* Tue Feb  8 2005 jsmeix@suse.de
- Replaced the descriptions-external file epkowa.desc from SANE
  by an extended SUSE version which has more model listed
  according to "man sane-epkowa" in the SUSE iscan package.
- Removed the automated "insserv" for sane-dev because this
  is now done by the YaST scanner config only if a SCSI scanner
  was set up (i.e. for USB scanners sane-dev is useless and
  therefore it should not run by default).
* Wed Feb  2 2005 jsmeix@suse.de
- Added a descriptions-external file hpaio.desc which was
  manually derived from the models.xml in the hplip package.
  Therefore there is a package version problem to have a fixed
  source file hpaio.desc but in the future an automated script
  may create an up to date hpaio.desc file.
* Tue Dec 28 2004 jsmeix@suse.de
- Changed how the descriptions and descriptions-external files
  are installed (those files are needed by YaST to create its
  scanner database): No longer via a doc/Makefile.in patch
  but directly in the spec file to avoid changes in the sources
  for SUSE-specific stuff.
- Added ':firmware "required"' entries for the respective scanners
  to the descriptions files (for gt68xx, artec_eplus48u, snapscan)
  so that YaST knows which scanners require a firmware upload.
- Replaced the descriptions-external file hpoj.desc from SANE
  by an extended SUSE version which has a list of explicite model
  names added so that YaST can show a detailed model list.
* Wed Nov 17 2004 jsmeix@suse.de
- Changed runlevel script "sane-dev":
  Avoid too long (perhaps infinite) waiting for "scanimage".
  Maximum wait is 10 seconds.
  Improved the format of the output.
* Wed Nov 10 2004 jsmeix@suse.de
- Changed "sane" runlevel script which sets permissions in /dev/
  and renamed it to "sane-dev" to avoid confusion with the
  SANE network daemon "saned" and its service name "sane-port"
  respectively "sane" (see SUSE bugzilla bnc#41233).
* Mon Nov  8 2004 jsmeix@suse.de
- new sane-backends version 1.0.15
- sane-frontends stuff is moved to the new package sane-frontends
* Wed Oct 20 2004 ro@suse.de
- locale rename: no -> nb
* Mon Sep 20 2004 jsmeix@suse.de
- Added a test in /etc/init.d/sane whether slpd is really
  running before "/etc/init.d/slpd reload" is done.
  (SUSE bugzilla bnc#42032).
* Wed Sep 15 2004 jsmeix@suse.de
- Added sane-backends-1.0.14-epson_d8.patch which fixes the
  problem with EPSON D8 function level scanners that have
  a transparency unit (SUSE bugzilla bnc#45075).
- Changed the file name of /etc/xinetd.d/sane.xinetd to
  /etc/xinetd.d/sane-port because xinetd ignores files
  with names containing a dot (SUSE bugzilla bnc#45313).
* Fri Aug 13 2004 jsmeix@suse.de
- Changed "sane" to "sane-port" in sane.xinetd see bug 41233
* Thu Jul 15 2004 jsmeix@suse.de
- Added libieee1284 support (by using the new libieee1284 package)
* Tue Jul 13 2004 jsmeix@suse.de
- Update sane-backends to version 1.0.14
* Wed Apr 21 2004 pth@suse.de
- Remove libtool macros from acinclude.m4 that caused build
  failures.
- Fix the cases of unnecessary type-punning, obsoleting the need
  for -fno-strict-aliasing.
- Fix pointer->int casts.
* Thu Apr  1 2004 jsmeix@suse.de
- Correction of what was done according to previous entry:
  Disable all entries in almost all descriptions-external/*.desc
  files because none of the external backends is included in the
  sane package
  except one: /usr/share/sane/descriptions-external/hpoj.desc
  because the hpoj backend is in fact available because it is
  in the hp-officeJet package which is installed by default
  see bug 37885
* Mon Mar 29 2004 jsmeix@suse.de
- Removed sane-descriptions-external-epkowa.desc.dif and
  disabled all entries in all descriptions-external/*.desc files
  because none of the external backends is included in the sane
  package (see bugzilla bnc#37169) and for details see
  .../doc/packages/sane/sane-backends/sane-backends-external.html
* Thu Mar 25 2004 jsmeix@suse.de
- Patch sane-descriptions-external-epkowa.desc.dif
  disables those entries in descriptions-external/epkowa.desc
  which are also in descriptions/epson.desc
  because we want to prefer the open source backend "epson"
  (see bugzilla bnc#36584).
* Tue Mar 23 2004 meissner@suse.de
- gimp plugins are now in ../2.0/...
* Mon Mar 22 2004 meissner@suse.de
- epson.conf triggers autodetect on mentioning of "usb", so just
  add this instead of all ids. #36585
* Fri Mar 12 2004 meissner@suse.de
- The plustek driver has its very own idea of a config file format,
  adapt the config patch.
* Mon Mar  8 2004 meissner@suse.de
- Updated the .conf files with most of the USB ids in use,
  so scanimage -L finds the scanners even without kernel module.
* Wed Feb 25 2004 meissner@suse.de
- Merged all system scanner ids into the hardcoded usermap,
  since newer kernels might no longer have the scanner module.
* Sat Feb 21 2004 ro@suse.de
- use no-strict-aliasing
* Sat Feb 21 2004 ro@suse.de
- fix gimp plugin link
* Sat Feb 21 2004 ro@suse.de
- updated frontends to 1.0.11-cvs to get gimp2 support
- use gtk2 for gimp
* Wed Feb 18 2004 meissner@suse.de
- actually apply the patch (and update it) and not just
  readd it to the sources.
* Mon Feb 16 2004 meissner@suse.de
- reapply resmgr patch.
* Fri Feb  6 2004 jsmeix@suse.de
- new versions sane-backends-1.0.13 and sane-frontends-1.0.11
- use the more important backend version number as package version
* Sat Jan 17 2004 meissner@suse.de
- fixed small typemismatch in sm3600.c
* Wed Nov 19 2003 adrian@suse.de
- use $HOSTNAME instead of $LOCALHOST in slp reg file
* Fri Nov 14 2003 adrian@suse.de
- use correct keyword "X-UnitedLinux-Should-Start" in runlevel script
* Thu Nov 13 2003 adrian@suse.de
- add xinetd file for sane daemon
- let slpd check for running saned via (x)inetd
- notify slpd, if using saned init script
* Wed Nov 12 2003 freitag@suse.de
- added registration file for slp daemon
* Mon Nov 10 2003 ro@suse.de
- use net-snmp instead of ucdsnmp
* Fri Oct 10 2003 hvogel@suse.de
- fix scanimage path in the init script
* Mon Jun 16 2003 meissner@suse.de
- Also use -L/..._lib, so we find -lresmgr on x86_64.
* Fri Jun 13 2003 meissner@suse.de
- Buildrooted.
- Added missing directories and files.
* Fri Jun  6 2003 freitag@suse.de
- update to backend version 1.0.12 - better support of current
  devices.
* Mon Mar  3 2003 freitag@suse.de
- fixed a filelist error which turned out to be a wrong lib link.
  Bug #24567
* Wed Feb 26 2003 meissner@suse.de
- Added one missing resmgr invocation.
* Mon Feb 17 2003 meissner@suse.de
- Added resmgr support for both SCSI and USB kernel mode.
  (basically use rsm_open_device). This will allow opening
  the /dev/*scanner devices as user without need for special
  permissions.
- Added a USB hotplug usermap which makes the sm3600 devices
  accessible for libusb. (The rest are handled by the yast2 scanner
  module).
* Mon Feb 17 2003 freitag@suse.de
- added epson backend directly from the author Karl Hein Kremer due
  to further changes to the USB base code. Removed the patch applied
  before again.
* Mon Feb 17 2003 freitag@suse.de
- patch applied to detect Epson scanners via libusb correctly.
  Thanks to Karl Heinz Kremer who sent it in.
* Mon Feb 10 2003 freitag@suse.de
- updated to backends version 1.0.11 which was suggested to avoid
  a possible security whole.
* Mon Feb  3 2003 freitag@suse.de
- update to stable version 1.0.10
  added gimp and gimp-devel to neededforbuild again to provide gimp
  support for xscanimage
* Fri Jan 31 2003 meissner@suse.de
- neededforbuild +resmgr, so libusb gets detected.
* Fri Jan 31 2003 freitag@suse.de
- added backend descriptions file to /usr/share/sane
  moved the style file from /usr/X11R6/lib to /usr/share/sane
  added sane postscript and dvi documentation as extra source
* Mon Jan 27 2003 freitag@suse.de
- update to version 1.0.10 pre 3
* Fri Jan 24 2003 freitag@suse.de
- update to pre version 1.0.10, final will follow soon.
  Much more scanner supported.
* Thu Oct 31 2002 freitag@suse.de
- update to final version 1.0.9
* Tue Oct 29 2002 ro@suse.de
- removed (old) libtool macros from acinclude.m4
* Fri Oct 18 2002 freitag@suse.de
- updated to pre version of 1.0.9 in advance for 1.0.9 and did some
  cleanup of the spec like removing a lot of neededforbuild deps
  and applied proper CFLAGS
  Added the gt68xx backend that supports expecially rf's new Mustek
  usb scanner
* Mon Sep  9 2002 freitag@suse.de
- fixed filelist and added libsane.so again.
* Mon Sep  9 2002 freitag@suse.de
- removed wrong lib libsane-hpoj from packlist, they came from package
  hp-officeJet accidentially.
* Fri Aug 16 2002 freitag@suse.de
- added prerequires (Bug #17983) and a postun procedure
* Mon Jul 29 2002 meissner@suse.de
- gphoto -> libgphoto2
* Sat Jul 27 2002 adrian@suse.de
- fix neededforbuild
* Thu Jul 18 2002 freitag@suse.de
- reapplied __KERNEL__-Patches
* Wed Jul 17 2002 freitag@suse.de
- update to sane version 1.0.8:
  - Network backend and saned update
  - documentation updates
  - bugfixes
  - updated backends
  - new backends
* Tue Mar 19 2002 freitag@suse.de
- fixed bug #14916
  This bug was caused by an segfault of scanimage which is used to
  find out which scanner are in operation on the network scan server.
  Since scanimage uses a one byte to small buffer in a string copy
  operation, a segfault happens.
  Fixed that bug by enlarging the buffer.
* Fri Mar  8 2002 freitag@suse.de
- fixed bug #14449
  That changes the sane startup script to work with the scanimage
  from sane package 1.0.7.
  Added a proper check for being root or not. only root may start
  or restart the service (which actually does nothing but setting
  file permissions for scsi scanner). See rcsane.diff for the patch
  applied on rc.sane. Note that rcsane.diff is not applied during
  the build process, but shows the differences against the former
  version of rc.sane
* Mon Feb 18 2002 freitag@suse.de
- fixed bug 13430 - updated to version 1.0.7 of sane. This broadens
  the scanner support.
* Wed Feb  6 2002 freitag@suse.de
- minor fixes in rc.sane: removed useless test on start variable
* Thu Jan 10 2002 freitag@suse.de
- updated to V. 1.0.6, provides bugfixes, gphoto2 changes and some
  new backends
- removed rc.config-template and used rpm macro instead to set the
  rc.config var.
- removed mustek_usb external source, because it is now part of the
  standard sane package.
* Tue Jan  8 2002 egmont@suselinux.hu
- changed `adjustscannerperm' to `sane' in init script
- removed bogus `probe' entry from the same script
* Wed Nov 21 2001 bjacke@suse.de
- remove useless provides
- make config files (noreplce)
- use libdir macro
* Wed Sep 12 2001 freitag@suse.de
- added support for Agfa SnapScan 1236U and updated to a later verion
  of mustek_usb-Backend, which provides better integration to the
  main backend module.
  Disabled all dll-entries in /etc/sane.d/dll.conf to avoid probs
  with wrong device detection which happend in the past. The yast
  module enables the correct one, added a README.SuSE to the sane
  package doc path that describes this change.
* Tue Sep  4 2001 freitag@suse.de
- added a rc-script that changes the permissions of scsi scanner
  devices if they are installed. The scsi device files are switched
  to permission 666 on startup and reverted back to 640 on shutdown.
* Mon Sep  3 2001 freitag@suse.de
- added a backend for mustek usb scanners.
* Wed Aug 29 2001 freitag@suse.de
- added support for scanning from HP all-in-one-devices.
  Therefore, package hp-officeJet is needed.
- added a configure option --docdir to get rid of build failiures
  on distributions which have the documentation not in share.
* Mon Aug 27 2001 freitag@suse.de
- applied patches for scanimage and sane-find-scanner that produce
  better parseable output for scripts etc. to help yast2 module.
- added a not yet in SANE released driver for mustek usb scanners,
  which are quite common in germany. The driver was initially written
  by a mustek engineer and was overtaken by the mustek backend
  maintainer of SANE.
* Tue Jul 17 2001 uli@suse.de
- disabled direct PIO access for PPC
* Thu Jul  5 2001 freitag@suse.de
- update to release 1.0.5
- documentation again created dynamically.
* Thu Jun 28 2001 freitag@suse.de
- updated to pre-1.0.5 version, 1.0.5 is expected soon
- patched sane-find-scanner to have a silent mode.
* Mon Apr  9 2001 freitag@suse.de
- applied snapscan-patch, fixed problem with missing gimp-plugin-link
* Fri Mar 30 2001 uli@suse.de
- fixed to build on PPC
* Fri Mar 23 2001 freitag@suse.de
- removed dependency to gimp, patch to solve timing probs with
  kernel 2.4
* Fri Jan  5 2001 freitag@suse.de
- updated to version 1.0.4
* Wed Dec 20 2000 ro@suse.de
- fixed symlink
* Mon Nov 20 2000 freitag@suse.de
- hide parport-scanner in standard sane distribution in dll.conf
* Wed Nov 15 2000 freitag@suse.de
- skipped parport-scanner driver also for axp
* Tue Nov  7 2000 freitag@suse.de
- skipped parport-scanner for ppc and sparc
* Mon Nov  6 2000 freitag@suse.de
- fixed Copyright/License-Field in SpecFile
* Fri Nov  3 2000 ro@suse.de
- fix neededforbuild for new package-names
* Thu Nov  2 2000 freitag@suse.de
- new version 1.0.3
  patch for Artec AS6E scanner
  patch for HP4200 PPort Scanner
* Mon Sep 25 2000 uli@suse.de
- fixed to build with new GIMP
* Mon Sep 25 2000 egger@suse.de
- Upgraded to 1.0.3.
- Added -DGIMP_ENABLE_COMPAT_CRUFT to build again.
- The specfile is quite messy... maybe the maintainer could clean
  that up, please?
* Mon Sep 25 2000 ro@suse.de
- changed neededforbuild: libgimpd -> gimpdev
* Tue Sep 12 2000 mhafner@suse.de
- added suse_update_config
* Tue Jun 27 2000 freitag@suse.de
- libs back to /usr/lib/sane - except libsane.so. and libsane-dll
* Fri Jun  2 2000 freitag@suse.de
- problem with missing headerfiles and wrong linked libs fixed.
* Wed May 24 2000 freitag@suse.de
- new configure switch --enable-scsibuffersize due to reported
  problems on the SANE-Mailinglist.
- installed *all* sane-libraries to /usr/lib
* Tue Mar 21 2000 bodammer@suse.de
- backend for Agfa SnapScan V0.8 again
* Mon Mar 20 2000 bodammer@suse.de
- update -> sane-1.0.2
  link to libsane-dll.so.1 included for xsane to work
* Sat Mar  4 2000 ro@suse.de
- removed libgimp from neededforbuild
* Thu Mar  2 2000 uli@suse.de
- moved man pages to _mandir
* Mon Feb  7 2000 kukuk@suse.de
- Don't check for asm/io.h, this will not work on SPARC
* Tue Jan 18 2000 bodammer@suse.de
- backend for Agfa SnapScan updated to V0.8
  works with new sg-modul from kernel > 2.2.5
* Fri Oct 15 1999 ro@suse.de
-xscanimage: renamed GIMP_EXTENSION to IS_GIMP_EXTENSION
  (GIMP_EXTENSION is already used as enumerator as of gimp-1.1.10)
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Thu Sep  2 1999 ro@suse.de
- update to 1.0.1
- fixed neededforbuild to get gimp-support back
- removed tcl tk from neededforbuild
* Sun Jul 18 1999 mha@suse.de
- removed '#' in front of /usr/sbin/saned in sane.spec
  for mb who isn't here today ;-)
* Tue Jul 13 1999 bs@suse.de
- use gtk and glib instead of gtkn and glibn
* Fri Mar 19 1999 mb@suse.de
- fixed gtkn, gtkndev, glibn, glibndev dependencies
* Thu Nov 26 1998 mb@suse.de
- major update to version 1.0
- new enhanced drivers for Abaton, Agfa Focus and Ricoh scanners
- Kodak DC210 still not supported
- Update for many drivers (Artec,Kodak,DC25,Microtek,Microtek2,Mustek
  UMAX and SnapScan).
- removed sgcheck. sgcheck now is in scsiinfo.
* Mon Nov 23 1998 mb@suse.de
- added sgcheck tool. It scans /proc/scsi/scsi and tells you
  exactly the generic scsi ID of your SCSI devices, respectively
  your scanner.
- added README.sgcheck
* Wed Nov 18 1998 ro@suse.de
- added libsane.so
* Tue Nov 17 1998 ro@suse.de
- adjust neededforbuild to current distribution
* Fri Nov 13 1998 mb@suse.de
- new version 0.74
- new and more scanners supported
- automatically detects attached scanners
* Mon May 25 1998 mb@suse.de
- new version 0.73
- according to author may still cause trouble with microtek2 scanners!!
- uses new gtk1.0.1
- added scanners to supported list
- lots of bug fixed
* Wed Mar 11 1998 ro@suse.de
- added libsane.so.0 to filelist
* Wed Feb  4 1998 mb@suse.de
- new version 0.70
- added support for various scanners, such as agfa, microtek etc.
- bugfixing for umax scanners
* Sun Sep 21 1997 mb@suse.de
  Initial version 0.63
